@@ -2,7 +2,7 @@ package App::GHPT::WorkSubmitter;
 
 use App::GHPT::Wrapper::OurMoose;
 
-our $VERSION = '1.000003';
+our $VERSION = '1.000004';
 
 use App::GHPT::Types qw( ArrayRef Bool PositiveInt Str );
 use App::GHPT::WorkSubmitter::AskPullRequestQuestions;
@@ -25,10 +25,11 @@ has project => (
 );
 
 has base => (
-    is            => 'ro',
-    isa           => Str,
-    default       => 'master',
-    documentation => 'The base of the pull request.',
+    is      => 'ro',
+    isa     => Str,
+    default => 'master',
+    documentation =>
+        'The branch against which you want base the pull request. This defaults to master.',
 );
 
 has dry_run => (
